/*
ThermistorVWK
 Auteur		: Henk Siewert
 Datum		: 19 december 2015
 Sensor		: Thermistor 10K
 Versie		: 01
 MCU		: TI M430G2553
 Language	: Energia C++
 Compiler	: Energia 0101E0016
 Editor		: NotePad++
 Systeem	: Windows XP Pro SP3
 WWW		: http://www.swtcomp.com
 */

#define ThermistorPIN P1_0		// Sensor op pin P1.0
#define INTERVAL 1000			// Interval voor meting in milliseconden
#define REF 3.53				// Referentie voltage = voedingsspanning LaunchPad
#define CAL 5.0					// Calibratie van de sensor

void setup()
{
  Serial.begin(9600);				// Open seriele verbinding
  pinMode(ThermistorPIN, INPUT);	// Zet sensorpin als input
  analogReference(DEFAULT);			// = Voedingsspanning
  pinMode(P1_3, OUTPUT);		    // Alle niet gebruikte pins aan GND
  digitalWrite(P1_3,LOW);			// 1.1 en 1.2 worden gebruikt door serieel
  pinMode(P1_4, OUTPUT);
  digitalWrite(P1_4,LOW);
  pinMode(P1_5, OUTPUT);
  digitalWrite(P1_5,LOW);
  pinMode(P1_6, OUTPUT);
  digitalWrite(P1_6,LOW);
  pinMode(P1_7, OUTPUT);
  digitalWrite(P1_7,LOW);
  pinMode(P2_0, OUTPUT);
  digitalWrite(P2_0,LOW);
  pinMode(P2_1, OUTPUT);
  digitalWrite(P2_1,LOW);
  pinMode(P2_2, OUTPUT);
  digitalWrite(P2_2,LOW);  
  pinMode(P2_3, OUTPUT);
  digitalWrite(P2_3,LOW);
  pinMode(P2_4, OUTPUT);
  digitalWrite(P2_4,LOW);
  pinMode(P2_5, OUTPUT);
  digitalWrite(P2_5,LOW);  
}

void loop()
{
getval();
}

/* ------------------------------------------------------------------
 Haal waarde op van ADC
 Maakt gebruik van de Steinhart-Hart thermistorformule:
 Temperature in Kelvin = 1 / {A + B[ln(R)] + C[ln(R)]^3}
 A = 0.001129148, B = 0.000234125 and C = 8.76741E-08
 -------------------------------------------------------------------*/
void getval()
{
  unsigned long Resistance;
  float Temp;
  unsigned long number = 0;
  unsigned long tijd = millis();
  unsigned long A2D = 0;
  float VOLT;
  
  do	// Haal INTERVAL x een meting op
  {
    A2D = A2D + ( analogRead(ThermistorPIN) - CAL );	// Met correctie
    number++;
  }
  while ( millis() - tijd < INTERVAL );

  A2D = A2D / number;	// Deel totaal door aantal metingen
  
  VOLT =  REF * A2D / 1024.0;

  Resistance = 10000.0 * (( 1024.0 / A2D ) - 1 );  // Gaat uit van een 10k thermistor.

  float lnTemp = logf(Resistance);
  
  Temp = 1 / (0.001129148 + (0.000234125 * lnTemp) + (0.0000000876741 * lnTemp * lnTemp * lnTemp));
  Temp = Temp - 273.15;	// Converteer Kelvin naar Celsius
  
  Serial.print("ADC = ");
  Serial.print(A2D);
  Serial.println(" van 1023");
  Serial.print("Voltage = ");
  Serial.print(VOLT);
  Serial.println(" Volt");
  Serial.print("Weerstand van thermistor = ");
  Serial.print(Resistance);
  Serial.println(" Ohm");
  Serial.print("Temperatuur = ");
  Serial.print(Temp);
  Serial.println(" Graden Celsius");
  Serial.println("");
  Serial.println("");
}


